aboutsummaryrefslogtreecommitdiffstats
path: root/src/fx.js
diff options
context:
space:
mode:
Diffstat (limited to 'src/fx.js')
-rw-r--r--src/fx.js10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/fx.js b/src/fx.js
index 7894b3e..b2b5d29 100644
--- a/src/fx.js
+++ b/src/fx.js
@@ -235,7 +235,7 @@ SVG.FX = SVG.invent({
}
for(i in s.styles){
- s.styles[i] = new SVG.MorphObj(this.target().style(i), s.styles[i])
+ s.styles[i] = new SVG.MorphObj(this.target().css(i), s.styles[i])
}
s.initialTransformation = this.target().matrixify()
@@ -608,14 +608,14 @@ SVG.FX = SVG.invent({
}
// apply animation which has to be applied with style()
for(i in s.styles){
at = [i].concat(s.styles[i]).map(function(el){
return typeof el !== 'string' && el.at ? el.at(s.ease(self.pos), self.pos) : el
})
- target.style.apply(target, at)
+ target.css.apply(target, at)
}
@@ -767,10 +767,10 @@ SVG.extend(SVG.FX, {
return this
}
// Add animatable styles
-, style: function(s, v) {
+, css: function(s, v) {
if (typeof s == 'object')
for (var key in s)
- this.style(key, s[key])
+ this.css(key, s[key])
else
this.add(s, v, 'styles')
@@ -608,14 +608,14 @@ SVG.FX = SVG.invent({
}
- // apply animation which has to be applied with style()
+ // apply animation which has to be applied with css()
for(i in s.styles){
at = [i].concat(s.styles[i]).map(function(el){